summaryrefslogtreecommitdiff
path: root/build
diff options
context:
space:
mode:
authorPeter Kokot <peterkokot@gmail.com>2018-10-09 21:17:19 +0200
committerPeter Kokot <peterkokot@gmail.com>2018-10-09 21:17:19 +0200
commit77c85b3119cc3aacbe2642c974bf88e512abd187 (patch)
tree9460a2b2715dea8f2a3fd57a4e8446dc866ee6d3 /build
parentf2856da6e833afc75ac58864a99625bed300e7da (diff)
parent1386b029f9834d9e77a644c58fc1d50006a82e67 (diff)
downloadphp-git-77c85b3119cc3aacbe2642c974bf88e512abd187.tar.gz
Merge branch 'PHP-7.3'
* PHP-7.3: [ci skip] Update UPGRADING about Autoconf version Bump minimum Autoconf requirement to 2.68
Diffstat (limited to 'build')
-rwxr-xr-xbuild/buildcheck.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/build/buildcheck.sh b/build/buildcheck.sh
index 7db31e2c0c..6601fc9943 100755
--- a/build/buildcheck.sh
+++ b/build/buildcheck.sh
@@ -25,18 +25,18 @@ if test -z "$PHP_AUTOCONF"; then
PHP_AUTOCONF='autoconf'
fi
# autoconf 2.64 or newer
ac_version=`$PHP_AUTOCONF --version 2>/dev/null|head -n 1|sed -e 's/^[^0-9]*//' -e 's/[a-z]* *$//'`
if test -z "$ac_version"; then
echo "buildconf: autoconf not found."
-echo " You need autoconf version 2.64 or newer installed"
+echo " You need autoconf version 2.68 or newer installed"
echo " to build PHP from Git."
exit 1
fi
IFS=.; set $ac_version; IFS=' '
-if test "$1" = "2" -a "$2" -lt "64" || test "$1" -lt "2"; then
+if test "$1" = "2" -a "$2" -lt "68" || test "$1" -lt "2"; then
echo "buildconf: autoconf version $ac_version found."
-echo " You need autoconf version 2.64 or newer installed"
+echo " You need autoconf version 2.68 or newer installed"
echo " to build PHP from Git."
exit 1
else
@@ -25,18 +25,18 @@ if test -z "$PHP_AUTOCONF"; then
PHP_AUTOCONF='autoconf'
fi
-# autoconf 2.64 or newer
+# autoconf 2.68 or newer
ac_version=`$PHP_AUTOCONF --version 2>/dev/null|head -n 1|sed -e 's/^[^0-9]*//' -e 's/[a-z]* *$//'`
if test -z "$ac_version"; then